"use client";
import { useEffect, useState } from "react";

import Image from "next/image";

import { Loader2, Star } from "lucide-react";
import { useLocale, useTranslations } from "next-intl";

import { ContentLines } from "@/components/shared/content-lines";
import { Button } from "@/components/ui/button";
import { Card } from "@/components/ui/card";
import { ImageBaseUrl } from "@/configs/api";
import { Link, Locale, } from "@/i18n/routing";
import { cn } from "@/lib/utils";
import { useProject } from "@/servers/data/use-project";


export function ProjectTestimonialSectionClient() {
	const locale = useLocale() as Locale;
	const isRTL = locale === "ar";
	const t = useTranslations();

	const { projects, isFetching, isLoading: _isLoading } = useProject();

	// console.log("projects: ", projects);

	const pageSize = 6;
	const [page, setPage] = useState(1);
	const [hasMore, setHasMore] = useState(true);
	const [visibleProjects, setVisibleProjects] = useState<any[]>([]);
	const [isLoading, setIsLoading] = useState(false);

	useEffect(() => {
		if (projects) {
			setHasMore(projects.length > pageSize * page);
			setVisibleProjects(projects.slice(0, pageSize * page));
		}
	}, [projects, page]);

	const handleLoadMore = () => {
		setIsLoading(true);
		setTimeout(() => {
			setPage(page + 1);
			setIsLoading(false);
		}, 3000);
	};

	return (
		<section className="py-16">
			{
				isFetching || _isLoading ? (
					<div className="flex justify-center">
						<Loader2 className="h-4 w-4 animate-spin" />
					</div>
				) : (

					<div className="container mx-auto max-w-7xl px-4">
						{/* Section Header */}
						<div className="mb-12 text-center">
							<ContentLines
								title={t("Our Projects")}
								underlineColor="custom-primary-accent"
								centered
								textColor="text-custom-primary-accent"
							/>
							<h2 className="mt-6 text-4xl font-bold text-gray-900">
								{t("Completed Projects")}
							</h2>
						</div>

						{!projects.length && (
							<div className="flex justify-center">
								<p className="text-gray-500">{t("No projects found")}</p>
							</div>
						)}

						<div className="grid gap-6 md:grid-cols-2" dir={isRTL ? "rtl" : "ltr"}>
							{visibleProjects?.map(
								({
									id,
									project_slug,
									title_ar,
									title_en,
									thumbnail,
									description_ar,
									description_en,
									city_ar,
									city_en,
									rating
								}: any) => (
									<Card
										key={id}
										className={cn(
											"relative overflow-hidden bg-[#F6F7FB] p-4",
											"rounded-sm transition-all duration-300",
											/* data.selectedId == id
											? "border-2 border-[#2895C8] shadow-lg"
											: */
											"border border-[#2895C8] shadow-md"
										)}
									>
										{/* Wave Pattern */}
										<div
											className={cn(
												"pointer-events-none absolute right-0 top-0 h-48 w-full sm:h-auto",
												isRTL ? "sm:left-0" : "sm:right-0"
											)}
										>
											<Image
												src="/wave.png"
												alt=""
												width={600}
												height={600}
												className="h-full w-full object-cover sm:object-contain"
											/>
										</div>

										{/* Content */}
										<div
											className={cn(
												"relative z-10 flex flex-col gap-6 sm:flex-row"
											)}
										>
											<div className="relative h-48 w-full overflow-hidden rounded-lg sm:h-32 sm:w-32 sm:shrink-0">
												<Image
													src={ImageBaseUrl + thumbnail?.image_path}
													alt={thumbnail?.name}
													fill
													className="object-cover"
												/>
											</div>
											<div className="flex-1">
												<p
													className={cn(
														"mb-6 text-sm leading-relaxed text-gray-700",
													)}
												>
													{isRTL ? description_ar : description_en}
												</p>
												<div
													className={cn(
														"flex flex-col gap-4 sm:flex-row sm:items-start sm:justify-between"
													)}
												>
													<div className="flex flex-col items-start justify-between gap-2">
														<h3
															className={cn(
																"text-lg font-medium text-[#2895C8]",
																isRTL && "text-right"
															)}
														>
															{isRTL ? title_ar : title_en}
														</h3>
														<p
															className={cn(
																"text-sm text-gray-600",
																isRTL && "text-right"
															)}
														>
															{isRTL ? city_ar : city_en}
														</p>
													</div>
													<div className="flex flex-col items-start gap-2 sm:items-center">
														<Button
															variant="ghost"
															className="w-full rounded-xl border border-[#2895C8] text-[#2895C8] hover:bg-[#2895C8] hover:text-white sm:w-auto"
															asChild
														>
															<Link
																href={`/projects/${id}` as any}
															>
																{t("Details")}
															</Link>
														</Button>
														<div className="flex items-center gap-0.5">
															{Array.from({ length: parseInt(rating) })?.map(
																(_, index) => (
																	<Star
																		key={index}
																		className="h-4 w-4 fill-yellow-400 text-yellow-400"
																	/>
																)
															)}
														</div>
													</div>
												</div>
											</div>
										</div>
									</Card>
								)
							)}
						</div>
						{
							hasMore && visibleProjects?.length > 0 &&
							<div className="flex justify-center mt-8">
								<Button variant="default" className="w-fit rounded-lg bg-custom-primary-accent text-white hover:bg-custom-primary-accent/90"
									onClick={handleLoadMore}
									disabled={isLoading}
								>
									{isLoading &&
										<Loader2 className="mr-2 h-4 w-4 animate-spin" />
									}
									{t("Load More")}
								</Button>
							</div>
						}
					</div>
				)
			}
		</section>
	);
}
